@@ -19,6 +19,7 @@
  * License along with dpkg; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+#include <config.h>
 
 #include <errno.h>
 #include <signal.h>
@@ -36,7 +37,6 @@
 #include <assert.h>
 #include <sys/wait.h>
 
-#include <config.h>
 #include <dpkg.h>
 #include <dpkg-db.h>
 
@@ -93,7 +93,7 @@ void deferred_configure(struct pkginfo *pkg) {
 				pkg->name, statusinfos[pkg->status].name);
 
 	if (dependtry > 1)
-		if (findbreakcycle(pkg,0))
+		if (findbreakcycle(pkg))
 			sincenothing= 0; 
 
 	varbufinit(&aemsgs);
