@@ -18,6 +18,7 @@
  * License along with dpkg; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+#include <config.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -32,7 +33,6 @@
 #include <limits.h>
 #include <ctype.h>
 
-#include <config.h>
 #include <dpkg.h>
 #include <dpkg-db.h>
 #include <version.h>
@@ -67,7 +67,6 @@ Usage: \n\
   dpkg --update-avail <Packages-file>      replace available packages info\n\
   dpkg --merge-avail <Packages-file>       merge with info from file\n\
   dpkg --clear-avail                       erase existing available info\n\
-  dpkg --command-fd <n>                    pass commands in on this file descriptor\n\
   dpkg --forget-old-unavail                forget uninstalled unavailable pkgs\n\
   dpkg -s|--status <package-name> ...      display package status details\n\
   dpkg -p|--print-avail <package-name> ... display available version details\n\
@@ -98,7 +97,8 @@ Options:\n\
   -G|--refuse-downgrade      Skip packages with earlier version than installed\n\
   -B|--auto-deconfigure      Install even if it would break some other package\n\
   --no-debsig                Do no try to verify package signatures\n\
-  --no-act                   Just say what we would do - don't do it\n\
+  --no-act|--dry-run|--simulate\n\
+                             Just say what we would do - don't do it\n\
   -D|--debug=<octal>         Enable debugging - see -Dhelp or --debug=help\n\
   --status-fd <n>            Send status change updates to file descriptor <n>\n\
   --ignore-depends=<package>,... Ignore dependencies involving <package>\n\
@@ -107,11 +107,11 @@ Options:\n\
   --abort-after <n>              Abort after encountering <n> errors\n\
 \n\
 Comparison operators for --compare-versions are:\n\
- lt le eq ne ge gt       (treat no version as earlier than any version);\n\
- lt-nl le-nl ge-nl gt-nl (treat no version as later than any version);\n\
+ lt le eq ne ge gt       (treat empty version as earlier than any version);\n\
+ lt-nl le-nl ge-nl gt-nl (treat empty version as later than any version);\n\
  < << <= = >= >> >       (only for compatibility with control file syntax).\n\
 \n\
-Use `dselect' for user-friendly package management.\n"),
+Use `dselect' or 'aptitude' for user-friendly package management.\n"),
 	    BACKEND, ADMINDIR) < 0) werr ("stdout");
 }
 
@@ -281,6 +281,7 @@ static void setpipe(const struct cmdinfo *cip, const char *value) {
     *lastpipe= nfmalloc(sizeof(struct pipef));
   }
   (*lastpipe)->fd= v;
+  (*lastpipe)->next= NULL;
 }
 
 static void setforce(const struct cmdinfo *cip, const char *value) {
@@ -394,6 +395,8 @@ static const struct cmdinfo cmdinfos[]= {
   { "pending",           'a',  0,  &f_pending,     0,  0,             1              },
   { "recursive",         'R',  0,  &f_recursive,   0,  0,             1              },
   { "no-act",             0,   0,  &f_noact,       0,  0,             1              },
+  { "dry-run",            0,   0,  &f_noact,       0,  0,             1              },
+  { "simulate",           0,   0,  &f_noact,       0,  0,             1              },
   { "no-debsig",          0,   0,  &f_nodebsig,    0,  0,             1              },
   {  0,                  'G',  0,  &fc_downgrade,  0,  0, /* alias for --refuse */ 0 },
   { "selected-only",     'O',  0,  &f_alsoselect,  0,  0,             0              },
