@@ -1,8 +1,8 @@
 /*
  * dpkg - main program for package management
- * dpkg-deb.h - external definitions for this program
+ * main.h - external definitions for this program
  *
- * Copyright (C) 1995 Ian Jackson <iwj10@cus.cam.ac.uk>
+ * Copyright (C) 1995 Ian Jackson <ian@chiark.greenend.org.uk>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -114,6 +114,7 @@ void updateavailable(const char *const *argv);
 void listpackages(const char *const *argv);
 void audit(const char *const *argv);
 void unpackchk(const char *const *argv);
+void showpackages(const char *const *argv);
 void searchfiles(const char *const *argv);
 void enqperpackage(const char *const *argv);
 void assertepoch(const char *const *argv);
@@ -123,7 +124,7 @@ void assertmulticonrep(const char *const *argv);
 void predeppackage(const char *const *argv);
 void printarch(const char *const *argv);
 void printinstarch(const char *const *argv);
-void cmpversions(const char *const *argv);
+void cmpversions(const char *const *argv) NONRETURNING;
 
 /* Intended for use as a comparison function for qsort when
  * sorting an array of pointers to struct pkginfo:
@@ -156,7 +157,7 @@ void cu_prermremove(int argc, void **argv);
 
 /* from errors.c */
 
-int nerrs;
+extern int nerrs;
 void print_error_perpackage(const char *emsg, const char *arg);
 void forcibleerr(int forceflag, const char *format, ...) PRINTFFORMAT(2,3);
 int reportbroken_retexitstatus(void);
@@ -216,7 +217,7 @@ void check_libver(void);
 int depisok(struct dependency *dep, struct varbuf *whynot,
             struct pkginfo **fixbyrm, int allowunconfigd);
 struct cyclesofarlink;
-int findbreakcycle(struct pkginfo *pkg, struct cyclesofarlink *sofar);
+int findbreakcycle(struct pkginfo *pkg);
 void describedepcon(struct varbuf *addto, struct dependency *dep);
 
 #endif /* MAIN_H */
